#!/usr/bin/env python
# -*- coding: utf-8 -*-
#===============================================================================
#
# Copyright (c) 2025 Chatopera Inc. <www.chatopera.com> All Rights Reserved
#
#
# File: /c/Users/Administrator/chatopera/embeddings-zh/embeddings_zh/__init__.py
# Author: Hai Liang Wang
# Date: 2025-05-30:10:07:37
#
#===============================================================================

"""
Embeddings Interfaces

https://python.langchain.com/api_reference/core/embeddings/langchain_core.embeddings.embeddings.Embeddings.html#langchain_core.embeddings.embeddings.Embeddings
"""
__copyright__ = "Copyright (c) Chatopera Inc. 2025. All Rights Reserved"
__author__ = "Hai Liang Wang"
__date__ = "2025-05-30:10:07:37"

import os, sys
curdir = os.path.dirname(os.path.abspath(__file__))
sys.path.append(curdir)

if sys.version_info[0] < 3:
    raise RuntimeError("Must be using Python 3")
else:
    unicode = str

from typing import Any, Dict, List, Optional
import synonyms

class EmbeddingsZh():
    
    def __init__(self, **kwargs: Any):
        pass

    def embed_documents(self, texts: List[str]) -> List[List[float]]:
        """Embeddings with Chatopera [Synonyms](https://github.com/chatopera/Synonyms) for chatbot, RAG.

        Args:
            texts: The list of texts to embed.

        Returns:
            List of embeddings, one for each text.
        """
        ret = []

        texts = list(map(lambda x: x.replace("\n", " "), texts))

        for text in texts:
            terms = synonyms.seg(text)[0]
            v = synonyms.bow(" ".join(terms))
            ret.append(v)

        return ret


    def embed_query(self, text: str) -> List[float]:
        """Compute query embeddings using Chatopera [Synonyms](https://github.com/chatopera/Synonyms) for chatbot, RAG.

        Args:
            text: The text to embed.

        Returns:
            Embeddings for the text.
        """
        return self.embed_documents([text])[0]



##########################################################################
# Testcases
##########################################################################
import unittest

# run testcase: python /c/Users/Administrator/chatopera/embeddings-zh/embeddings_zh/__init__.py Test.testExample
class Test(unittest.TestCase):
    '''
    
    '''
    def setUp(self):
        pass

    def tearDown(self):
        pass

    def test_001(self):
        print("test_001")

def test():
    '''
    Run tests, two ways available
    '''

    # run as a suite
    #suite = unittest.TestSuite()
    #suite.addTest(Test("test_001"))
    #runner = unittest.TextTestRunner()
    #runner.run(suite)

    # run as main, accept pass testcase name with argvs
    unittest.main()

def main():
    test()

if __name__ == '__main__':
    main()



# -*- coding: utf-8 -*-
from setuptools import setup, find_packages
LONGDOC = """
embeddings-zh
=====================

Embeddings with Chatopera Synonyms for chatbot, RAG.

https://github.com/chatopera/embeddings-zh

Model: https://github.com/chatopera/Synonyms

pip install -U embeddings-zh

Usage::

    from embeddings_zh import EmbeddingsZh

    emb = EmbeddingsZh()
    vector1 = emb.embed_documents([texts]) # e.g. emb.embed_documents(["今天天气怎么样", "有什么推荐"])
    vector2 emb.embed_query(texts) # e.g. emb.embed_documents("有什么推荐")
"""

setup(
    name='embeddings-zh',
    version='0.0.5',
    description='Embeddings with Chatopera Synonyms for chatbot, RAG.',
    long_description=LONGDOC,
    author='Hai Liang Wang',
    author_email='info@chatopera.com',
    url='https://github.com/chatopera/embeddings-zh',
    license="Chunsong Public License, version 1.0",
    classifiers=[
        'Intended Audience :: Developers',
        'Operating System :: OS Independent',
        'Natural Language :: Chinese (Simplified)',
        'Natural Language :: Chinese (Traditional)',
        'Programming Language :: Python',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.11'
    ],
    keywords='embeddings,nlp',
    packages=find_packages(),
    install_requires=[
        'synonyms>=3.23.7'
    ],
    package_data={
        'synonyms': [
            'LICENSE']})
